@@ -9,7 +9,8 @@ class SimpleStringFormCriterion(
 
     meta_type      = 'SimpleStringFormCriterion'
     archetype_name = 'Simple String Form Criterion'
-    shortDesc = 'Form: Text'
+    shortDesc = (
+        'Form: ' + simplestring.ATSimpleStringCriterion.shortDesc)
 
 criteria.registerCriterion(
     SimpleStringFormCriterion,
